==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/igc-geographic-polyline-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcStyleShapeEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicPolylineSeries } from "./GeographicPolylineSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
/**
 * Series class used for displaying multiple polylines, in a geographic context, for datasources which contain multiple lists of points.
*/
var IgcGeographicPolylineSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicPolylineSeriesComponent, _super);
    function IgcGeographicPolylineSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._styleShape = null;
        _this._styleShape_wrapped = null;
        return _this;
    }
    IgcGeographicPolylineSeriesComponent.prototype.createImplementation = function () {
        return new GeographicPolylineSeries();
    };
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicPolylineSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicPolylineSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicPolylineSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicPolylineSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent = names;
            }
            return IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicPolylineSeriesComponent.register = function () {
        if (!IgcGeographicPolylineSeriesComponent._isElementRegistered) {
            IgcGeographicPolylineSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicPolylineSeriesComponent.htmlTagName, IgcGeographicPolylineSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "isPolyline", {
        /**
         * Gets whether the current series shows a polyline shape.
        */
        get: function () {
            return this.i.e5;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "shapeFill", {
        /**
         * Gets or sets the fill brush.
        */
        get: function () {
            return this.i.vj ? this.i.vj.fill : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.vj.fill = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "shapeStroke", {
        /**
         * Gets or sets the stroke brush.
        */
        get: function () {
            return this.i.vj ? this.i.vj.stroke : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.vj.stroke = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "shapeStrokeThickness", {
        /**
         * Gets or sets the stroke thickness.
        */
        get: function () {
            return this.i.vj ? this.i.vj.strokeThickness : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.vj.strokeThickness = +v;
            this._a("shapeStrokeThickness", this.i.vj.strokeThickness);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "shapeOpacity", {
        /**
         * Gets or sets the opacity.
        */
        get: function () {
            return this.i.vj ? this.i.vj.opacity : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.vj.opacity = +v;
            this._a("shapeOpacity", this.i.vj.opacity);
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicPolylineSeriesComponent.prototype.ensureShapeStyle = function () {
        if (this.i.vj) {
            return;
        }
        this.i.vj = new Style();
    };
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "styleShape", {
        get: function () {
            return this._styleShape;
        },
        set: function (ev) {
            var _this = this;
            if (this._styleShape_wrapped !== null) {
                this.i.styleShape = delegateRemove(this.i.styleShape, this._styleShape_wrapped);
                this._styleShape_wrapped = null;
                this._styleShape = null;
            }
            this._styleShape = ev;
            this._styleShape_wrapped = function (o, e) {
                var outerArgs = new IgcStyleShapeEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeStyleShape) {
                    _this.beforeStyleShape(_this, outerArgs);
                }
                if (_this._styleShape) {
                    _this._styleShape(_this, outerArgs);
                }
            };
            this.i.styleShape = delegateCombine(this.i.styleShape, this._styleShape_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent = null;
    IgcGeographicPolylineSeriesComponent.htmlTagName = "igc-geographic-polyline-series";
    IgcGeographicPolylineSeriesComponent._isElementRegistered = false;
    return IgcGeographicPolylineSeriesComponent;
}(IgcGeographicShapeSeriesBaseComponent));
export { IgcGeographicPolylineSeriesComponent };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/igc-geographic-polyline-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcStyleShapeEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicShapeSeriesBaseComponent } from "./igc-geographic-shape-series-base-component";
import { GeographicPolylineSeries } from "./GeographicPolylineSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
import { Style } from "igniteui-webcomponents-core";
/**
 * Series class used for displaying multiple polylines, in a geographic context, for datasources which contain multiple lists of points.
*/
var IgcGeographicPolylineSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicPolylineSeriesComponent, _super);
    function IgcGeographicPolylineSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._styleShape = null;
        _this._styleShape_wrapped = null;
        return _this;
    }
    IgcGeographicPolylineSeriesComponent.prototype.createImplementation = function () {
        return new GeographicPolylineSeries();
    };
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicPolylineSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicPolylineSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicPolylineSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicPolylineSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent = names;
            }
            return IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicPolylineSeriesComponent.register = function () {
        if (!IgcGeographicPolylineSeriesComponent._isElementRegistered) {
            IgcGeographicPolylineSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicPolylineSeriesComponent.htmlTagName, IgcGeographicPolylineSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "isPolyline", {
        /**
         * Gets whether the current series shows a polyline shape.
        */
        get: function () {
            return this.i.fr;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "shapeFill", {
        /**
         * Gets or sets the fill brush.
        */
        get: function () {
            return this.i.yp ? this.i.yp.fill : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.yp.fill = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "shapeStroke", {
        /**
         * Gets or sets the stroke brush.
        */
        get: function () {
            return this.i.yp ? this.i.yp.stroke : null;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.yp.stroke = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "shapeStrokeThickness", {
        /**
         * Gets or sets the stroke thickness.
        */
        get: function () {
            return this.i.yp ? this.i.yp.strokeThickness : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.yp.strokeThickness = +v;
            this._a("shapeStrokeThickness", this.i.yp.strokeThickness);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "shapeOpacity", {
        /**
         * Gets or sets the opacity.
        */
        get: function () {
            return this.i.yp ? this.i.yp.opacity : NaN;
        },
        set: function (v) {
            this.ensureShapeStyle();
            this.i.yp.opacity = +v;
            this._a("shapeOpacity", this.i.yp.opacity);
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicPolylineSeriesComponent.prototype.ensureShapeStyle = function () {
        if (this.i.yp) {
            return;
        }
        this.i.yp = new Style();
    };
    Object.defineProperty(IgcGeographicPolylineSeriesComponent.prototype, "styleShape", {
        get: function () {
            return this._styleShape;
        },
        set: function (ev) {
            var _this = this;
            if (this._styleShape_wrapped !== null) {
                this.i.styleShape = delegateRemove(this.i.styleShape, this._styleShape_wrapped);
                this._styleShape_wrapped = null;
                this._styleShape = null;
            }
            this._styleShape = ev;
            this._styleShape_wrapped = function (o, e) {
                var outerArgs = new IgcStyleShapeEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeStyleShape) {
                    _this.beforeStyleShape(_this, outerArgs);
                }
                if (_this._styleShape) {
                    _this._styleShape(_this, outerArgs);
                }
            };
            this.i.styleShape = delegateCombine(this.i.styleShape, this._styleShape_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicPolylineSeriesComponent._observedAttributesIgcGeographicPolylineSeriesComponent = null;
    IgcGeographicPolylineSeriesComponent.htmlTagName = "igc-geographic-polyline-series";
    IgcGeographicPolylineSeriesComponent._isElementRegistered = false;
    return IgcGeographicPolylineSeriesComponent;
}(IgcGeographicShapeSeriesBaseComponent));
export { IgcGeographicPolylineSeriesComponent };
